# epik8s-tools

`epik8s-tools` is a set of utilities for generating Kubernetes Helm charts for EPICS-based systems.

## Installation

To install the tool via `pip`, run:

```bash
pip install epik8s-tools
